/manager

Server Status

Manager
List Applications | HTML Manager Help | Manager Help | Complete Server Status

Server Information
Tomcat Version | JVM Version | JVM Vendor | OS Name | OS Version | OS Architecture
Apache Tomcat/6.0.24 | 1.6.0_26-b03 | Sun Microsystems Inc. | Linux | 2.6.32-31-generic | i386

# JVM

Free memory: 53.57 MB Total memory: 62.43 MB Max memory: 126.43 MB

# http-8080

Max threads: 200 Current thread count: 2 Current thread busy: 1
Max processing time: 65 ms Processing time: 0.122 s Request count: 12 Error count: 7 Bytes received: 0.00 MB Bytes sent: 0.03 MB

Stage | Time | B Sent | B Recv | Client | VHost | Request
--- | --- | --- | --- | --- | --- | ---
S | 3 ms | 0 KB | 0 KB | 0:0:0:0:0:0:0:1 | localhost | GET /manager/status HTTP/1.1
R | ? | ? | ? | ? | ? | ?

P: Parse and prepare request S: Service F: Finishing R: Ready K: Keepalive

# jk-8009

Max threads: 200 Current thread count: 4 Current thread busy: 1
Max processing time: 0 ms Processing time: 0.0 s Request count: 0 Error count: 0 Bytes received: 0.00 MB Bytes sent: 0.00 MB

Stage | Time | B Sent | B Recv | Client | VHost | Request
--- | --- | --- | --- | --- | --- | ---

P: Parse and prepare request S: Service F: Finishing R: Ready K: Keepalive

Copyright © 1999-2010, Apache Software Foundation